@@ -22,6 +22,8 @@
 
 #include "connectioneditor.h"
 #include "connectiondetaileditor.h"
+
+#include "debug.h"
 #include "editoridentitymodel.h"
 #include "editorproxymodel.h"
 #include "networkmodel.h"
@@ -29,6 +31,7 @@
 #include "uiutils.h"
 #include "ui_connectioneditor.h"
 #include "vpnuiplugin.h"
+
 #include <networkmodelitem.h>
 
 #include <QFileDialog>
@@ -46,10 +49,10 @@
 #include <KMessageBox>
 #include <KService>
 #include <KServiceTypeTrader>
-#include <KShell>
 #include <KStandardAction>
 #include <KXMLGUIFactory>
 #include <KWallet/Wallet>
+#include <KSharedConfig>
 
 #include <NetworkManagerQt/ActiveConnection>
 #include <NetworkManagerQt/Connection>
@@ -80,12 +83,12 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     initializeConnections();
     initializeMenu();
 
-    connect(m_editor->connectionsWidget, SIGNAL(pressed(QModelIndex)),
-            SLOT(slotItemClicked(QModelIndex)));
-    connect(m_editor->connectionsWidget, SIGNAL(doubleClicked(QModelIndex)),
-            SLOT(slotItemDoubleClicked(QModelIndex)));
-    connect(m_editor->connectionsWidget, SIGNAL(customContextMenuRequested(QPoint)),
-            SLOT(slotContextMenuRequested(QPoint)));
+    KConfigGroup grp(KSharedConfig::openConfig(), "ConnectionsWidget");
+    m_editor->connectionsWidget->header()->restoreState(grp.readEntry<QByteArray>("state", QByteArray()));
+
+    connect(m_editor->connectionsWidget, &QTreeView::pressed, this, &ConnectionEditor::slotItemClicked);
+    connect(m_editor->connectionsWidget, &QTreeView::doubleClicked, this, &ConnectionEditor::slotItemDoubleClicked);
+    connect(m_editor->connectionsWidget, &QTreeView::customContextMenuRequested, this, &ConnectionEditor::slotContextMenuRequested);
     connect(m_menu->menu(), SIGNAL(triggered(QAction*)),
             SLOT(addConnection(QAction*)));
     connect(NetworkManager::settingsNotifier(), SIGNAL(connectionAdded(QString)),
@@ -101,24 +104,33 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
 
         generalGroup.writeEntry("FirstStart", false);
     }
+
+    QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.debug = false"));
+    QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.warning = true"));
 }
 
 ConnectionEditor::~ConnectionEditor()
 {
+    KConfigGroup grp(KSharedConfig::openConfig(), "ConnectionsWidget");
+    grp.writeEntry("state", m_editor->connectionsWidget->header()->saveState());
     delete m_editor;
 }
 
+void ConnectionEditor::activateAndRaise()
+{
+    setWindowState((windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
+}
+
 void ConnectionEditor::initializeMenu()
 {
     m_menu = new KActionMenu(QIcon::fromTheme("list-add"), i18n("Add"), this);
     m_menu->menu()->setSeparatorsCollapsible(false);
     m_menu->setDelayed(false);
 
-    QAction * action = m_menu->addSeparator();
-    action->setText(i18n("Hardware"));
+    m_menu->menu()->addSection(i18n("Hardware"));
 
     // TODO Adsl
-    action = new QAction(i18n("DSL"), this);
+    QAction * action = new QAction(i18n("DSL"), this);
     action->setData(NetworkManager::ConnectionSettings::Pppoe);
     m_menu->addAction(action);
     action = new QAction(i18n("InfiniBand"), this);
@@ -149,8 +161,7 @@ void ConnectionEditor::initializeMenu()
     action->setData(NetworkManager::ConnectionSettings::Wimax);
     m_menu->addAction(action);
 
-    action = m_menu->addSeparator();
-    action->setText(i18nc("Virtual hardware devices, eg Bridge, Bond", "Virtual"));
+    m_menu->menu()->addSection(i18nc("Virtual hardware devices, eg Bridge, Bond", "Virtual"));
 
     action = new QAction(i18n("Bond"), this);
     action->setData(NetworkManager::ConnectionSettings::Bond);
@@ -167,12 +178,11 @@ void ConnectionEditor::initializeMenu()
     m_menu->addAction(action);
 #endif
 
-    action = m_menu->addSeparator();
-    action->setText(i18n("VPN"));
+    m_menu->menu()->addSection(i18n("VPN"));
 
     const KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin");
     foreach (const KService::Ptr & service, services) {
-        qDebug() << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
+        qCDebug(PLASMA_NM) << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
 
         action = new QAction(service->name(), this);
         action->setData(NetworkManager::ConnectionSettings::Vpn);
@@ -182,25 +192,35 @@ void ConnectionEditor::initializeMenu()
 
     actionCollection()->addAction("add_connection", m_menu);
 
-    QAction * kAction = new QAction(QIcon::fromTheme("configure"), i18n("Edit..."), this);
+    QAction * kAction = new QAction(QIcon::fromTheme("network-connect"), i18n("Connect"), this);
     kAction->setEnabled(false);
-    connect(kAction, SIGNAL(triggered()), SLOT(editConnection()));
+    connect(kAction, &QAction::triggered, this, &ConnectionEditor::connectConnection);
+    actionCollection()->addAction("connect_connection", kAction);
+
+    kAction = new QAction(QIcon::fromTheme("network-disconnect"), i18n("Disconnect"), this);
+    kAction->setEnabled(false);
+    connect(kAction, &QAction::triggered, this, &ConnectionEditor::disconnectConnection);
+    actionCollection()->addAction("disconnect_connection", kAction);
+
+    kAction = new QAction(QIcon::fromTheme("configure"), i18n("Edit..."), this);
+    kAction->setEnabled(false);
+    connect(kAction, &QAction::triggered, this, &ConnectionEditor::editConnection);
     actionCollection()->addAction("edit_connection", kAction);
 
     kAction = new QAction(QIcon::fromTheme("edit-delete"), i18n("Delete"), this);
     kAction->setEnabled(false);
-    kAction->setShortcut(QKeySequence::Delete);
-    connect(kAction, SIGNAL(triggered()), SLOT(removeConnection()));
+    connect(kAction, &QAction::triggered, this, &ConnectionEditor::removeConnection);
     actionCollection()->addAction("delete_connection", kAction);
+    actionCollection()->setDefaultShortcut(kAction, QKeySequence::Delete);
 
     kAction = new QAction(QIcon::fromTheme("document-import"), i18n("Import VPN..."), this);
     actionCollection()->addAction("import_vpn", kAction);
-    connect(kAction, SIGNAL(triggered()), SLOT(importVpn()));
+    connect(kAction, &QAction::triggered, this, &ConnectionEditor::importVpn);
 
     kAction = new QAction(QIcon::fromTheme("document-export"), i18n("Export VPN..."), this);
     actionCollection()->addAction("export_vpn", kAction);
     kAction->setEnabled(false);
-    connect(kAction, SIGNAL(triggered()), SLOT(exportVpn()));
+    connect(kAction, &QAction::triggered, this, &ConnectionEditor::exportVpn);
 
     KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
     KStandardAction::quit(this, SLOT(close()), actionCollection());
@@ -218,13 +238,13 @@ void ConnectionEditor::addConnection(QAction* action)
     NetworkManager::ConnectionSettings::ConnectionType type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toUInt());
     const QString vpnType = action->property("type").toString();
 
-    qDebug() << "Adding new connection of type " << type;
+    // qCDebug(PLASMA_NM) << "Adding new connection of type " << type;
 
     if (type == NetworkManager::ConnectionSettings::Gsm) { // launch the mobile broadband wizard, both gsm/cdma
 #if WITH_MODEMMANAGER_SUPPORT
         QWeakPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
         if (wizard.data()->exec() == QDialog::Accepted && wizard.data()->getError() == MobileProviders::Success) {
-            qDebug() << "Mobile broadband wizard finished:" << wizard.data()->type() << wizard.data()->args();
+            qCDebug(PLASMA_NM) << "Mobile broadband wizard finished:" << wizard.data()->type() << wizard.data()->args();
 
             if (wizard.data()->args().count() == 2) {
                 QVariantMap tmp = qdbus_cast<QVariantMap>(wizard.data()->args().value(1));
@@ -243,10 +263,10 @@ void ConnectionEditor::addConnection(QAction* action)
                 } else if (wizard.data()->type() == NetworkManager::ConnectionSettings::Cdma) {
                     connectionSettings->setting(NetworkManager::Setting::Cdma)->fromMap(tmp);
                 } else {
-                    qWarning() << Q_FUNC_INFO << "Unhandled setting type";
+                    qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unhandled setting type";
                 }
             } else {
-                qWarning() << Q_FUNC_INFO << "Unexpected number of args to parse";
+                qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unexpected number of args to parse";
             }
         }
 
@@ -261,7 +281,7 @@ void ConnectionEditor::addConnection(QAction* action)
         if (type == NetworkManager::ConnectionSettings::Vpn) {
             NetworkManager::VpnSetting::Ptr vpnSetting = connectionSettings->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
             vpnSetting->setServiceType(vpnType);
-            qDebug() << "VPN type: " << vpnType;
+            // qCDebug(PLASMA_NM) << "VPN type: " << vpnType;
         }
 
         if (type == NetworkManager::ConnectionSettings::Wired || type == NetworkManager::ConnectionSettings::Wireless) {
@@ -303,7 +323,11 @@ void ConnectionEditor::addConnection(QAction* action)
     QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(connectionSettings, true);
 
     if (editor->exec() == QDialog::Accepted) {
-        qDebug() << editor->setting();
+        if (type == NetworkManager::ConnectionSettings::Vpn) {
+            qCDebug(PLASMA_NM) << "Adding new connection of type " << vpnType;
+        } else {
+            qCDebug(PLASMA_NM) << "Adding new connection of type " << NetworkManager::ConnectionSettings::typeAsString(type);
+        }
         m_handler->addConnection(editor->setting());
     }
 
@@ -417,9 +441,9 @@ void ConnectionEditor::slotContextMenuRequested(const QPoint&)
     const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
 
     if (isAvailable && !isActive) {
-        menu->addAction(QIcon::fromTheme("user-online"), i18n("Connect"), this, SLOT(connectConnection()));
+        menu->addAction(actionCollection()->action("connect_connection"));
     } else if (isAvailable && isActive) {
-        menu->addAction(QIcon::fromTheme("user-offline"), i18n("Disconnect"), this, SLOT(disconnectConnection()));
+        menu->addAction(actionCollection()->action("disconnect_connection"));
     }
     menu->addAction(actionCollection()->action("edit_connection"));
     menu->addAction(actionCollection()->action("delete_connection"));
@@ -432,14 +456,21 @@ void ConnectionEditor::slotItemClicked(const QModelIndex &index)
         return;
     }
 
-//     qDebug() << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
+    // qCDebug(PLASMA_NM) << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
 
     if (index.parent().isValid()) { // category
+        actionCollection()->action("connect_connection")->setEnabled(false);
+        actionCollection()->action("disconnect_connection")->setEnabled(false);
         actionCollection()->action("edit_connection")->setEnabled(false);
         actionCollection()->action("delete_connection")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
     } else {                       //connection
+        const bool isActive = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
+        const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
+
+        actionCollection()->action("connect_connection")->setEnabled(isAvailable && !isActive);
+        actionCollection()->action("disconnect_connection")->setEnabled(isAvailable && isActive);
         actionCollection()->action("edit_connection")->setEnabled(true);
         actionCollection()->action("delete_connection")->setEnabled(true);
         const bool isVpn = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(index.data(NetworkModel::TypeRole).toUInt()) ==
@@ -454,10 +485,10 @@ void ConnectionEditor::slotItemDoubleClicked(const QModelIndex &index)
         return;
     }
 
-//     qDebug() << "Double clicked item" << index.data(NetworkModel::UuidRole).toString();
+    // qCDebug(PLASMA_NM) << "Double clicked item" << index.data(NetworkModel::UuidRole).toString();
 
     if (index.parent().isValid()) { // category
-        qDebug() << "double clicked on the root item which is not editable";
+        // qCDebug(PLASMA_NM) << "double clicked on the root item which is not editable";
         return;
     }
 
@@ -505,11 +536,13 @@ void ConnectionEditor::storeSecrets(const QMap< QString, QMap< QString, QString
             return;
         }
 
-        if (!wallet->hasFolder("Network Management")) {
-            wallet->createFolder("Network Management");
+        const QString folderName(QStringLiteral("Network Management"));
+
+        if (!wallet->hasFolder(folderName)) {
+            wallet->createFolder(folderName);
         }
 
-        if (wallet->hasFolder("Network Management") && wallet->setFolder("Network Management")) {
+        if (wallet->hasFolder(folderName) && wallet->setFolder(folderName)) {
             int count = 0;
             foreach (const QString & entry, map.keys()) {
                 QString connectionUuid = entry.split(';').first();
@@ -533,7 +566,7 @@ void ConnectionEditor::importVpn()
     foreach (const KService::Ptr &service, services) {
         VpnUiPlugin * vpnPlugin = service->createInstance<VpnUiPlugin>(this);
         if (vpnPlugin) {
-            extensions += vpnPlugin->supportedFileExtensions() % QLatin1Literal(" ");
+            extensions += vpnPlugin->supportedFileExtensions() % QStringLiteral(" ");
             delete vpnPlugin;
         }
     }
@@ -541,26 +574,26 @@ void ConnectionEditor::importVpn()
     const QString filename = QFileDialog::getOpenFileName(this, i18n("Import VPN Connection"), QDir::homePath(), extensions.simplified());
     if (!filename.isEmpty()) {
         QFileInfo fi(filename);
-        const QString ext = QLatin1Literal("*.") % fi.suffix();
-        qDebug() << "Importing VPN connection" << filename << "extension:" << ext;
+        const QString ext = QStringLiteral("*.") % fi.suffix();
+        qCDebug(PLASMA_NM) << "Importing VPN connection " << filename << "extension:" << ext;
 
         foreach (const KService::Ptr &service, services) {
             VpnUiPlugin * vpnPlugin = service->createInstance<VpnUiPlugin>(this);
             if (vpnPlugin && vpnPlugin->supportedFileExtensions().contains(ext)) {
-                qDebug() << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
+                qCDebug(PLASMA_NM) << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
 
                 NMVariantMapMap connection = vpnPlugin->importConnectionSettings(filename);
 
-                //qDebug() << "Raw connection:" << connection;
+                // qCDebug(PLASMA_NM) << "Raw connection:" << connection;
 
                 NetworkManager::ConnectionSettings connectionSettings;
                 connectionSettings.fromMap(connection);
                 connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
 
-                //qDebug() << "Converted connection:" << connectionSettings;
+                // qCDebug(PLASMA_NM) << "Converted connection:" << connectionSettings;
 
                 m_handler->addConnection(connectionSettings.toMap());
-//                 qDebug() << "Adding imported connection under id:" << conId;
+                // qCDebug(PLASMA_NM) << "Adding imported connection under id:" << conId;
 
                 if (connection.isEmpty()) { // the "positive" part will arrive with connectionAdded
                     m_editor->messageWidget->animatedShow();
@@ -598,11 +631,11 @@ void ConnectionEditor::exportVpn()
 
     NetworkManager::VpnSetting::Ptr vpnSetting = connSettings->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
 
-    qDebug() << "Exporting VPN connection" << connection->name() << "type:" << vpnSetting->serviceType();
+    qCDebug(PLASMA_NM) << "Exporting VPN connection" << connection->name() << "type:" << vpnSetting->serviceType();
 
     QString error;
-    VpnUiPlugin * vpnPlugin = KServiceTypeTrader::createInstanceFromQuery<VpnUiPlugin>(QString::fromLatin1("PlasmaNetworkManagement/VpnUiPlugin"),
-                                                                                       QString::fromLatin1("[X-NetworkManager-Services]=='%1'").arg(vpnSetting->serviceType()),
+    VpnUiPlugin * vpnPlugin = KServiceTypeTrader::createInstanceFromQuery<VpnUiPlugin>(QStringLiteral("PlasmaNetworkManagement/VpnUiPlugin"),
+                                                                                       QStringLiteral("[X-NetworkManager-Services]=='%1'").arg(vpnSetting->serviceType()),
                                                                                        this, QVariantList(), &error);
 
     if (vpnPlugin) {
@@ -631,6 +664,6 @@ void ConnectionEditor::exportVpn()
         }
         delete vpnPlugin;
     } else {
-        qWarning() << "Error getting VpnUiPlugin for export:" << error;
+        qCWarning(PLASMA_NM) << "Error getting VpnUiPlugin for export:" << error;
     }
 }
