@@ -23,6 +23,7 @@
 
 #include <KAboutData>
 #include <KLocalizedString>
+#include <KDBusService>
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -47,12 +48,14 @@ int main(int argc, char *argv[])
     about.addCredit(i18n("Will Stephenson"), i18n("VPN plugins"), "wstephenson@kde.org");
     about.addCredit(i18n("Ilia Kats"), i18n("VPN plugins"), "ilia-kats@gmx.net");
     about.setProductName("plasma-nm/editor");
-    about.setProgramIconName("preferences-system-network");
 
     KAboutData::setApplicationData(about);
+    KDBusService service(KDBusService::Unique);
 
     ConnectionEditor * editor = new ConnectionEditor();
     editor->show();
 
+    QObject::connect(&service, &KDBusService::activateRequested, editor, &ConnectionEditor::activateAndRaise);
+
     return app.exec();
 }
