@@ -1,7 +1,7 @@
 /*
     Copyright 2011 Lamarque Souza <lamarque@kde.org>
     Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -26,31 +26,21 @@
 #include "mobileconnectionwizard.h"
 #include <ModemManagerQt/manager.h>
 #endif
-#include <QDBusObjectPath>
+
+#include "dbusobjectmanager.h"
+class QDBusServiceWatcher;
 
 class BluetoothMonitor: public QObject
 {
 Q_OBJECT
-Q_CLASSINFO("D-Bus Interface", "org.kde.plasmanetworkmanagement")
 public:
     explicit BluetoothMonitor(QObject * parent);
     ~BluetoothMonitor();
 
-public Q_SLOTS:
-    Q_SCRIPTABLE void addBluetoothConnection(const QString & bdAddr, const QString & service);
-private Q_SLOTS:
-    void init();
-#if WITH_MODEMMANAGER_SUPPORT
-    void modemAdded(const QString &udi);
-#endif
+    void addBluetoothConnection(const QString & bdAddr, const QString & service);
+
 private:
-    QString mBdaddr;
-    QString mService;
-    QString mDunDevice;
-    QString mDevicePath;
-    QString mDeviceName;
-#if WITH_MODEMMANAGER_SUPPORT
-    QWeakPointer<MobileConnectionWizard> mobileConnectionWizard;
-#endif
+    QDBusServiceWatcher *mServiceWatcher;
+    org::freedesktop::DBus::ObjectManager *mBluezInterface;
 };
 #endif
