@@ -1,6 +1,7 @@
 /*
     Copyright 2009 Will Stephenson <wstephenson@kde.org>
     Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
+    Copyright 2014 Jan Grulich <jgrulich@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -19,20 +20,18 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "debug.h"
 #include "modemmonitor.h"
 
 #include <QDBusPendingReply>
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <kdeversion.h>
-#include <QDebug>
 
 #include <ModemManager/ModemManager.h>
-#include <ModemManagerQt/manager.h>
-#include <ModemManagerQt/modemdevice.h>
-#include <ModemManagerQt/modem.h>
-#include <ModemManagerQt/sim.h>
+#include <ModemManagerQt/Manager>
+#include <ModemManagerQt/Modem>
+#include <ModemManagerQt/Sim>
 
 #include "pindialog.h"
 
@@ -48,9 +47,9 @@ ModemMonitor::ModemMonitor(QObject * parent)
     Q_D(ModemMonitor);
     d->dialog.clear();
 
-    QObject::connect(ModemManager::notifier(), SIGNAL(modemAdded(QString)), SLOT(modemAdded(QString)));
+    QObject::connect(ModemManager::notifier(), SIGNAL(modemAdded(QString)), SLOT(unlockModem(QString)));
     foreach (const ModemManager::ModemDevice::Ptr &iface, ModemManager::modemDevices()) {
-        modemAdded(iface->uni());
+        unlockModem(iface->uni());
     }
 }
 
@@ -59,19 +58,19 @@ ModemMonitor::~ModemMonitor()
     delete d_ptr;
 }
 
-void ModemMonitor::modemAdded(const QString & udi)
+void ModemMonitor::unlockModem(const QString &modemUni)
 {
     Q_D(ModemMonitor);
 
-    ModemManager::ModemDevice::Ptr modemDevice = ModemManager::findModemDevice(udi);
     ModemManager::Modem::Ptr modem;
+    ModemManager::ModemDevice::Ptr modemDevice = ModemManager::findModemDevice(modemUni);
     if (modemDevice) {
         modem = modemDevice->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
     } else {
         return;
     }
 
-    connect(modem.data(), SIGNAL(unlockRequiredChanged(MMModemLock)), SLOT(requestPin(MMModemLock)));
+    connect(modem.data(), SIGNAL(unlockRequiredChanged(MMModemLock)), SLOT(requestPin(MMModemLock)), Qt::UniqueConnection);
 
     if (d->dialog || (modem && modem->unlockRequired() == MM_MODEM_LOCK_NONE) || (modem && modem->unlockRequired() == MM_MODEM_LOCK_UNKNOWN)) {
         return;
@@ -87,7 +86,7 @@ void ModemMonitor::modemAdded(const QString & udi)
 void ModemMonitor::requestPin(MMModemLock lock)
 {
     Q_D(ModemMonitor);
-    qDebug() << "unlockRequired == " << lock;
+    qCDebug(PLASMA_NM) << "unlockRequired == " << lock;
     // Handle just SIM-PIN and SIM-PUK, because some other types may cause problems and they are not also handled by nm-applet
     if (lock == MM_MODEM_LOCK_NONE || lock == MM_MODEM_LOCK_UNKNOWN || (lock != MM_MODEM_LOCK_SIM_PIN && lock != MM_MODEM_LOCK_SIM_PUK)) {
         return;
@@ -99,7 +98,7 @@ void ModemMonitor::requestPin(MMModemLock lock)
     }
 
     if (d->dialog) {
-        qDebug() << "PinDialog already running";
+        qCDebug(PLASMA_NM) << "PinDialog already running";
         return;
     }
 
@@ -139,7 +138,7 @@ void ModemMonitor::requestPin(MMModemLock lock)
         goto OUT;
     }
 
-    qDebug() << "Sending unlock code";
+    qCDebug(PLASMA_NM) << "Sending unlock code";
 
     {
         ModemManager::Sim::Ptr sim;
