@@ -21,7 +21,7 @@
 #ifndef PLASMA_NM_CDMA_WIDGET_H
 #define PLASMA_NM_CDMA_WIDGET_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 #include <NetworkManagerQt/Setting>
 
@@ -39,9 +39,9 @@ public:
     explicit CdmaWidget(const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(), QWidget* parent = 0, Qt::WindowFlags f = 0);
     virtual ~CdmaWidget();
 
-    void loadConfig(const NetworkManager::Setting::Ptr &setting);
+    void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
 
-    QVariantMap setting(bool agentOwned = false) const;
+    QVariantMap setting(bool agentOwned = false) const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void showPassword(bool show);
