@@ -33,7 +33,7 @@
 #include <NetworkManagerQt/Utils>
 
 HwAddrComboBox::HwAddrComboBox(QWidget *parent) :
-    KComboBox(parent), m_dirty(false)
+    QComboBox(parent), m_dirty(false)
 {
     setEditable(true);
     setInsertPolicy(QComboBox::NoInsert);
@@ -59,7 +59,7 @@ QString HwAddrComboBox::hwAddress() const
     else
         result = currentText();
 
-    //qDebug() << "Result:" << currentIndex() << result;
+    // qCDebug(PLASMA_NM)() << "Result:" << currentIndex() << result;
 
     return result;
 }
@@ -80,7 +80,7 @@ void HwAddrComboBox::init(const NetworkManager::Device::Type &deviceType, const
 {
     m_initialAddress = address;
 
-    //qDebug() << "Initial address:" << m_initialAddress;
+    // qCDebug(PLASMA_NM) << "Initial address:" << m_initialAddress;
 
     QString deviceName;
     foreach(const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
@@ -100,7 +100,7 @@ void HwAddrComboBox::init(const NetworkManager::Device::Type &deviceType, const
     const int index = findData(m_initialAddress);
     if (index == -1) {
         if (!m_initialAddress.isEmpty()) {
-            QString text = QString("%1 (%2)").arg(deviceName).arg(m_initialAddress);
+            const QString text = QStringLiteral("%1 (%2)").arg(deviceName).arg(m_initialAddress);
             insertItem(0, text, m_initialAddress);
         } else {
             insertItem(0, m_initialAddress, m_initialAddress);
@@ -114,7 +114,7 @@ void HwAddrComboBox::init(const NetworkManager::Device::Type &deviceType, const
 void HwAddrComboBox::addAddressToCombo(const NetworkManager::Device::Ptr &device)
 {
     const QVariant data = hwAddressFromDevice(device);
-    //qDebug() << "Data:" << data;
+    // qCDebug(PLASMA_NM) << "Data:" << data;
 
     QString name;
     if (device->state() == NetworkManager::Device::Activated)
@@ -122,14 +122,14 @@ void HwAddrComboBox::addAddressToCombo(const NetworkManager::Device::Ptr &device
     else
         name = device->interfaceName();
 
-    //qDebug() << "Name:" << name;
+    // qCDebug(PLASMA_NM) << "Name:" << name;
 
     if (!data.isNull()) {
         if (name == data.toString()) {
             addItem(data.toString(), data);
         }
         else {
-            addItem(QString("%1 (%2)").arg(name).arg(data.toString()), data);
+            addItem(QStringLiteral("%1 (%2)").arg(name).arg(data.toString()), data);
         }
     }
 }
