@@ -21,7 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef INTDELEGATE_H
 #define INTDELEGATE_H
 
-#include <KLineEdit>
+#include <QLineEdit>
 #include <QStandardItem>
 #include <QStandardItemModel>
 
@@ -35,7 +35,7 @@ public:
     IntDelegate(int min, int max, QObject * parent = 0);
     virtual ~IntDelegate();
 
-    QWidget * createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    QWidget * createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
 
 private:
     int m_min;
