@@ -18,21 +18,18 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "ipv6routeswidget.h"
-
-#include <QDebug>
 #include <QStandardItem>
 #include <QStandardItemModel>
 #include <QNetworkAddressEntry>
 
 #include <KAcceleratorManager>
-#include <KLineEdit>
 #include <KLocalizedString>
 
 #include "ui_ipv6routes.h"
 
 #include "ipv6delegate.h"
 #include "intdelegate.h"
+#include "ipv6routeswidget.h"
 
 class IpV6RoutesWidget::Private
 {
@@ -57,7 +54,7 @@ IpV6RoutesWidget::IpV6RoutesWidget(QWidget * parent)
 {
     d->ui.setupUi(this);
     d->ui.tableViewAddresses->setModel(&d->model);
-    d->ui.tableViewAddresses->horizontalHeader()->setResizeMode(QHeaderView::ResizeToContents);
+    d->ui.tableViewAddresses->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
 
     IpV6Delegate *ipDelegate = new IpV6Delegate(this);
     IntDelegate *netmaskDelegate = new IntDelegate(0,128,this);
@@ -116,7 +113,7 @@ void IpV6RoutesWidget::setRoutes(const QList<NetworkManager::IpRoute> &list)
     d->model.removeRows(0, d->model.rowCount());
     foreach (const NetworkManager::IpRoute &route, list) {
         QList<QStandardItem *> item;
-        qDebug() << route.ip();
+        // qCDebug(PLASMA_NM) << route.ip();
         item << new QStandardItem(route.ip().toString())
              << new QStandardItem(QString::number(route.prefixLength(), 10))
              << new QStandardItem(route.nextHop().toString())
@@ -186,7 +183,7 @@ void IpV6RoutesWidget::removeRoute()
 
 void IpV6RoutesWidget::selectionChanged(const QItemSelection & selected)
 {
-    qDebug() << "selectionChanged";
+    // qCDebug(PLASMA_NM) << "selectionChanged";
     d->ui.pushButtonRemove->setEnabled(!selected.isEmpty());
 }
 
