@@ -23,7 +23,6 @@
 #include "uiutils.h"
 
 #include <QVBoxLayout>
-#include <QDebug>
 
 #include <KLocalizedString>
 #include <KIconLoader>
@@ -31,8 +30,8 @@
 
 #include <NetworkManagerQt/ModemDevice>
 
-#include <ModemManagerQt/manager.h>
-#include <ModemManagerQt/modem.h>
+#include <ModemManagerQt/Manager>
+#include <ModemManagerQt/Modem>
 
 #define NUMBER_OF_STATIC_ENTRIES 3
 
