@@ -35,6 +35,11 @@
 #include <NetworkManagerQt/WirelessSetting>
 #include <NetworkManagerQt/ActiveConnection>
 
+#if WITH_MODEMMANAGER_SUPPORT
+#include <ModemManagerQt/Manager>
+#include <ModemManagerQt/ModemDevice>
+#endif
+
 #include <QDBusError>
 #include <QIcon>
 
@@ -71,19 +76,19 @@ void Handler::activateConnection(const QString& connection, const QString& devic
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
     if (!con) {
-        qWarning() << "Not possible to activate this connection";
+        qCWarning(PLASMA_NM) << "Not possible to activate this connection";
         return;
     }
 
     if (con->settings()->connectionType() == NetworkManager::ConnectionSettings::Vpn) {
         NetworkManager::VpnSetting::Ptr vpnSetting = con->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
         if (vpnSetting) {
-            qWarning() << "Checking VPN" << con->name() << "type:" << vpnSetting->serviceType();
+            qCDebug(PLASMA_NM) << "Checking VPN" << con->name() << "type:" << vpnSetting->serviceType();
             // get the list of supported VPN service types
             const KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin",
                                                                               QString::fromLatin1("[X-NetworkManager-Services]=='%1'").arg(vpnSetting->serviceType()));
             if (services.isEmpty()) {
-                qWarning() << "VPN" << vpnSetting->serviceType() << "not found, skipping";
+                qCWarning(PLASMA_NM) << "VPN" << vpnSetting->serviceType() << "not found, skipping";
                 KNotification *notification = new KNotification("MissingVpnPlugin", KNotification::CloseOnTimeout, this);
                 notification->setComponentName("networkmanagement");
                 notification->setTitle(con->name());
@@ -95,11 +100,32 @@ void Handler::activateConnection(const QString& connection, const QString& devic
         }
     }
 
+#if WITH_MODEMMANAGER_SUPPORT
+    if (con->settings()->connectionType() == NetworkManager::ConnectionSettings::Gsm) {
+        NetworkManager::ModemDevice::Ptr nmModemDevice = NetworkManager::findNetworkInterface(device).objectCast<NetworkManager::ModemDevice>();
+        if (nmModemDevice) {
+            ModemManager::ModemDevice::Ptr mmModemDevice = ModemManager::findModemDevice(nmModemDevice->udi());
+            if (mmModemDevice) {
+                ModemManager::Modem::Ptr modem = mmModemDevice->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+                if (modem && modem->unlockRequired() > MM_MODEM_LOCK_NONE) {
+                    QDBusInterface managerIface("org.kde.plasmanetworkmanagement", "/org/kde/plasmanetworkmanagement", "org.kde.plasmanetworkmanagement", QDBusConnection::sessionBus(), this);
+                    managerIface.call("unlockModem", mmModemDevice->uni());
+                    connect(modem.data(), &ModemManager::Modem::unlockRequiredChanged, this, &Handler::unlockRequiredChanged);
+                    m_tmpConnectionPath = connection;
+                    m_tmpDevicePath = device;
+                    m_tmpSpecificPath = specificObject;
+                    return;
+                }
+            }
+        }
+    }
+#endif
+
     QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::activateConnection(connection, device, specificObject);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::ActivateConnection);
     watcher->setProperty("connection", con->name());
-    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(replyFinished(QDBusPendingCallWatcher*)));
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
 void Handler::addAndActivateConnection(const QString& device, const QString& specificObject, const QString& password)
@@ -192,7 +218,7 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
         QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
         watcher->setProperty("action", Handler::AddAndActivateConnection);
         watcher->setProperty("connection", settings->name());
-        connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(replyFinished(QDBusPendingCallWatcher*)));
+        connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
     }
 
     settings.clear();
@@ -212,7 +238,7 @@ void Handler::deactivateConnection(const QString& connection, const QString& dev
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
     if (!con) {
-        qWarning() << "Not possible to deactivate this connection";
+        qCWarning(PLASMA_NM) << "Not possible to deactivate this connection";
         return;
     }
 
@@ -236,7 +262,7 @@ void Handler::deactivateConnection(const QString& connection, const QString& dev
 
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::DeactivateConnection);
-    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(replyFinished(QDBusPendingCallWatcher*)));
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
 void Handler::disconnectAll()
@@ -352,7 +378,7 @@ void Handler::removeConnection(const QString& connection)
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
     if (!con || con->uuid().isEmpty()) {
-        qWarning() << "Not possible to remove connection " << connection;
+        qCWarning(PLASMA_NM) << "Not possible to remove connection " << connection;
         return;
     }
 
@@ -368,7 +394,7 @@ void Handler::removeConnection(const QString& connection)
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::RemoveConnection);
     watcher->setProperty("connection", con->name());
-    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(replyFinished(QDBusPendingCallWatcher*)));
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
 void Handler::updateConnection(const NetworkManager::Connection::Ptr& connection, const NMVariantMapMap& map)
@@ -415,37 +441,30 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
         switch (action) {
             case Handler::ActivateConnection:
                 notification = new KNotification("FailedToActivateConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to activate %1", watcher->property("connection").toString()));
                 break;
             case Handler::AddAndActivateConnection:
                 notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to add %1", watcher->property("connection").toString()));
                 break;
             case Handler::AddConnection:
                 notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to add connection %1", watcher->property("connection").toString()));
                 break;
             case Handler::DeactivateConnection:
                 notification = new KNotification("FailedToDeactivateConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to deactivate %1", watcher->property("connection").toString()));
                 break;
             case Handler::RemoveConnection:
                 notification = new KNotification("FailedToRemoveConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to remove %1", watcher->property("connection").toString()));
                 break;
             case Handler::RequestScan:
                 notification = new KNotification("FailedToRequestScan", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to request scan"));
                 break;
             case Handler::UpdateConnection:
                 notification = new KNotification("FailedToUpdateConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to update connection %1", watcher->property("connection").toString()));
                 break;
             default:
@@ -453,6 +472,7 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
         }
 
         if (notification) {
+            notification->setComponentName("networkmanagement");
             notification->setText(error);
             notification->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(KIconLoader::SizeHuge));
             notification->sendEvent();
@@ -464,20 +484,14 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
         switch (action) {
             case Handler::AddConnection:
                 notification = new KNotification("ConnectionAdded", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
-                notification->setTitle(watcher->property("connection").toString());
                 notification->setText(i18n("Connection %1 has been added", watcher->property("connection").toString()));
                 break;
             case Handler::RemoveConnection:
                 notification = new KNotification("ConnectionRemoved", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
-                notification->setTitle(watcher->property("connection").toString());
                 notification->setText(i18n("Connection %1 has been removed", watcher->property("connection").toString()));
                 break;
             case Handler::UpdateConnection:
                 notification = new KNotification("ConnectionUpdated", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
-                notification->setTitle(watcher->property("connection").toString());
                 notification->setText(i18n("Connection %1 has been updated", watcher->property("connection").toString()));
                 break;
             default:
@@ -485,6 +499,8 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
         }
 
         if (notification) {
+            notification->setComponentName("networkmanagement");
+            notification->setTitle(watcher->property("connection").toString());
             notification->setPixmap(QIcon::fromTheme("dialog-information").pixmap(KIconLoader::SizeHuge));
             notification->sendEvent();
         }
@@ -492,3 +508,12 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
 
     watcher->deleteLater();
 }
+
+#if WITH_MODEMMANAGER_SUPPORT
+void Handler::unlockRequiredChanged(MMModemLock modemLock)
+{
+    if (modemLock == MM_MODEM_LOCK_NONE) {
+        activateConnection(m_tmpConnectionPath, m_tmpDevicePath, m_tmpSpecificPath);
+    }
+}
+#endif
