@@ -23,6 +23,8 @@
 #include "openconnectauthworkerthread.h"
 #include "ui_openconnectauth.h"
 
+#include "debug.h"
+
 #include <QDialog>
 #include <KLocalizedString>
 #include <QPushButton>
@@ -35,7 +37,6 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QComboBox>
-#include <QDebug>
 #include <QDomDocument>
 #include <QMutex>
 #include <QWaitCondition>
@@ -70,7 +71,6 @@ public:
     Ui_OpenconnectAuth ui;
     NetworkManager::VpnSetting::Ptr setting;
     struct openconnect_info *vpninfo;
-    QStringList certificateFingerprints;
     NMStringMap secrets;
     QMutex mutex;
     QWaitCondition workerWaiting;
@@ -197,10 +197,6 @@ void OpenconnectAuthWidget::readSecrets()
 
     d->secrets = d->setting->secrets();
 
-    if (!d->secrets[NM_OPENCONNECT_KEY_GWCERT].isEmpty()) {
-        d->certificateFingerprints.append(d->secrets[NM_OPENCONNECT_KEY_GWCERT]);
-    }
-
     if (!d->secrets["xmlconfig"].isEmpty()) {
         const QByteArray config = QByteArray::fromBase64(d->secrets["xmlconfig"].toAscii());
 
@@ -240,11 +236,6 @@ void OpenconnectAuthWidget::readSecrets()
         d->ui.chkAutoconnect->setChecked(true);
         QTimer::singleShot(0, this, SLOT(connectHost()));
     }
-
-    if (!d->secrets["certsigs"].isEmpty()) {
-        d->certificateFingerprints.append(d->secrets["certsigs"].split('\t'));
-    }
-    d->certificateFingerprints.removeDuplicates();
 }
 
 void OpenconnectAuthWidget::acceptDialog()
@@ -279,7 +270,7 @@ void OpenconnectAuthWidget::connectHost()
     i = d->ui.cmbHosts->itemData(i).toInt();
     const VPNHost &host = d->hosts.at(i);
     if (openconnect_parse_url(d->vpninfo, host.address.toAscii().data())) {
-        qWarning() << "Failed to parse server URL" << host.address;
+        qCWarning(PLASMA_NM) << "Failed to parse server URL" << host.address;
         openconnect_set_hostname(d->vpninfo, OC3DUP(host.address.toAscii().data()));
     }
     if (!openconnect_get_urlpath(d->vpninfo) && !host.group.isEmpty())
@@ -313,7 +304,6 @@ QVariantMap OpenconnectAuthWidget::setting(bool agentOwned) const
     openconnect_get_cert_sha1(d->vpninfo, cert, fingerprint);
 #endif
     secrets.insert(QLatin1String(NM_OPENCONNECT_KEY_GWCERT), QLatin1String(fingerprint));
-    secrets.insert(QLatin1String("certsigs"), d->certificateFingerprints.join("\t"));
     secrets.insert(QLatin1String("autoconnect"), d->ui.chkAutoconnect->isChecked() ? "yes" : "no");
 
     NMStringMap::iterator i = secrets.begin();
@@ -396,7 +386,7 @@ void OpenconnectAuthWidget::addFormInfo(const QString &iconName, const QString &
 
     QLabel *text = new QLabel(this);
     text->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
-    text->setWordWrap(false);
+    text->setWordWrap(true);
     layout->addWidget(text);
 
     icon->setPixmap(QIcon::fromTheme(iconName).pixmap(KIconLoader::SizeSmall));
@@ -491,7 +481,16 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
 {
     Q_D(OpenconnectAuthWidget);
 
-    if (!d->certificateFingerprints.contains(fingerprint)) {
+    const QString host = QLatin1String(openconnect_get_hostname(d->vpninfo));
+    const QString port = QString::number(openconnect_get_port(d->vpninfo));
+    const QString key = QString("certificate:%1:%2").arg(host,  port);
+    const QString value = d->secrets.value(key);
+
+#if !OPENCONNECT_CHECK_VER(5,0)
+#define openconnect_check_peer_cert_hash(v,d) strcmp(d, fingerprint.toUtf8().data())
+#endif
+
+    if (openconnect_check_peer_cert_hash(d->vpninfo, value.toUtf8().data())) {
         QWidget *widget = new QWidget();
         QVBoxLayout *verticalLayout;
         QHBoxLayout *horizontalLayout;
@@ -541,7 +540,6 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
         dialog->layout()->addWidget(buttons);
 
         if(dialog.data()->exec() == QDialog::Accepted) {
-            d->certificateFingerprints.append(fingerprint);
             *accepted = true;
         } else {
             *accepted = false;
@@ -553,6 +551,8 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
     } else {
         *accepted = true;
     }
+    if (*accepted)
+        d->secrets.insert(key, QString(fingerprint));
     d->mutex.lock();
     d->workerWaiting.wakeAll();
     d->mutex.unlock();
