@@ -36,6 +36,8 @@
 #include "openvpnwidget.h"
 #include "openvpnauth.h"
 
+#include <arpa/inet.h>
+
 #include "nm-openvpn-service.h"
 
 K_PLUGIN_FACTORY_WITH_JSON(OpenVpnUiPluginFactory, "plasmanetworkmanagement_openvpnui.json", registerPlugin<OpenVpnUiPlugin>();)
@@ -67,7 +69,6 @@ K_PLUGIN_FACTORY_WITH_JSON(OpenVpnUiPluginFactory, "plasmanetworkmanagement_open
 #define TLS_CLIENT_TAG "tls-client"
 #define TLS_REMOTE_TAG "tls-remote"
 #define TUNMTU_TAG "tun-mtu"
-#define REDIRECT_GATEWAY_TAG "redirect-gateway"
 #define KEY_DIRECTION_TAG "key-direction"
 
 #define BEGIN_KEY_CA_TAG "<ca>"
@@ -204,7 +205,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
     bool proxy_set = false;
     bool have_pass = false;
     bool have_sk = false;
-    bool have_redirect_gateway = false;
     int key_direction = -1;
 
     QTextStream in(&impFile);
@@ -497,10 +497,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
             continue;
         }
 
-        if (key_value[0] == REDIRECT_GATEWAY_TAG) {
-            have_redirect_gateway = true;
-            continue;
-        }
         if (key_value[0] == KEY_DIRECTION_TAG) {
             if (key_value.count() == 2) {
                 key_direction = key_value[1].toInt();
@@ -556,7 +552,23 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
 
         // Import X-NM-Routes if present
         if (key_value[0] == "X-NM-Routes") {
-            ipv4Data.insert("X-NM-Routes", key_value[1]);
+            QList<NetworkManager::IpRoute> list;
+            for (int i = 1; i < key_value.count(); i++) {
+                NetworkManager::IpRoute ipRoute;
+                ipRoute.setIp(QHostAddress(key_value[1].split('/').first()));
+                ipRoute.setPrefixLength(key_value[1].split('/').at(1).toInt());
+                list << ipRoute;
+            }
+            QList<QList<uint> > dbusRoutes;
+            foreach (const NetworkManager::IpRoute &route, list) {
+                QList<uint> dbusRoute;
+                dbusRoute << htonl(route.ip().toIPv4Address())
+                        << route.prefixLength()
+                        << htonl(route.nextHop().toIPv4Address())
+                        << route.metric();
+                dbusRoutes << dbusRoute;
+            }
+            ipv4Data.insert("routes", QVariant::fromValue(dbusRoutes));
             continue;
         }
     }
@@ -810,13 +822,7 @@ bool OpenVpnUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionS
         }
     }
 
-    // Export never default setting.
     NetworkManager::Ipv4Setting::Ptr ipv4Setting = connection->setting(NetworkManager::Setting::Ipv4).dynamicCast<NetworkManager::Ipv4Setting>();
-    if (!ipv4Setting->neverDefault()) {
-        line = QString(REDIRECT_GATEWAY_TAG) + '\n';
-        expFile.write(line.toLatin1());
-    }
-    
     // Export X-NM-Routes
     if (!ipv4Setting->routes().isEmpty()) {
         QString routes;
@@ -825,7 +831,7 @@ bool OpenVpnUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionS
         }
         if (!routes.isEmpty()) {
             routes = "X-NM-Routes " + routes.trimmed();
-            expFile.write(routes.toLatin1());
+            expFile.write(routes.toLatin1() + '\n');
         }
     }
     // Add hard-coded stuff
