@@ -211,12 +211,22 @@ void OpenVpnAdvancedWidget::loadConfig()
     if (dataMap.contains(NM_OPENVPN_KEY_TLS_REMOTE)) {
         m_ui->subjectMatch->setText(dataMap[NM_OPENVPN_KEY_TLS_REMOTE]);
     }
+
+    if (dataMap.contains(NM_OPENVPN_KEY_REMOTE_CERT_TLS)) {
+        const QString remoteCertTls = dataMap[NM_OPENVPN_KEY_REMOTE_CERT_TLS];
+        m_ui->chkRemoteCertTls->setChecked(true);
+        m_ui->labelRemoteCertTls->setEnabled(true);
+        m_ui->cmbRemoteCertTls->setEnabled(true);
+        m_ui->cmbRemoteCertTls->setCurrentIndex(remoteCertTls == QLatin1String("server") ? 0 : 1);
+    }
+
     m_ui->useExtraTlsAuth->setChecked(!dataMap[NM_OPENVPN_KEY_TA].isEmpty());
     m_ui->kurlTlsAuthKey->setUrl(QUrl::fromLocalFile(dataMap[NM_OPENVPN_KEY_TA]) );
     if (dataMap.contains(NM_OPENVPN_KEY_TA_DIR)) {
         const uint tlsAuthDirection = dataMap[NM_OPENVPN_KEY_TA_DIR].toUInt();
         m_ui->cboDirection->setCurrentIndex(tlsAuthDirection + 1);
     }
+
     // Proxies
     if (dataMap[NM_OPENVPN_KEY_PROXY_TYPE] == "http") {
         m_ui->cmbProxyType->setCurrentIndex(Private::EnumProxyType::HTTP);
@@ -323,6 +333,11 @@ NetworkManager::VpnSetting::Ptr OpenVpnAdvancedWidget::setting() const
     if (!m_ui->subjectMatch->text().isEmpty()) {
         data.insert(QLatin1String(NM_OPENVPN_KEY_TLS_REMOTE), m_ui->subjectMatch->text());
     }
+
+    if (m_ui->chkRemoteCertTls->isChecked()) {
+        data.insert(QLatin1String(NM_OPENVPN_KEY_REMOTE_CERT_TLS), m_ui->cmbRemoteCertTls->currentText().toLower());
+    }
+
     if (m_ui->useExtraTlsAuth->isChecked()) {
         QUrl tlsAuthKeyUrl = m_ui->kurlTlsAuthKey->url();
         if (!tlsAuthKeyUrl.isEmpty()) {
