@@ -21,6 +21,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "debug.h"
 #include "vpnc.h"
 
 #include <QStandardPaths>
@@ -31,13 +32,14 @@
 #include <KSharedConfig>
 #include <KMessageBox>
 #include <KLocalizedString>
-#include <QDebug>
 #include "nm-vpnc-service.h"
 
 #include <NetworkManagerQt/Connection>
 #include <NetworkManagerQt/VpnSetting>
 #include <NetworkManagerQt/Ipv4Setting>
 
+#include <arpa/inet.h>
+
 #include "vpncwidget.h"
 #include "vpncauth.h"
 
@@ -82,7 +84,7 @@ void VpncUiPluginPrivate::ciscoDecryptFinished(int exitCode, QProcess::ExitStatu
 void VpncUiPluginPrivate::ciscoDecryptError(QProcess::ProcessError pError)
 {
     if (!pError) {
-        qDebug() << "Error in executing cisco-decrypt";
+        qCWarning(PLASMA_NM) << "Error in executing cisco-decrypt";
         KMessageBox::error(0, i18n("Error decrypting the obfuscated password"), i18n("Error"), KMessageBox::Notify);
     }
     decryptedPasswd.clear();
@@ -125,7 +127,7 @@ QString VpncUiPlugin::supportedFileExtensions() const
 
 NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
 {
-    qDebug() << "Importing Cisco VPN connection from " << fileName;
+    // qCDebug(PLASMA_NM) << "Importing Cisco VPN connection from " << fileName;
 
     VpncUiPluginPrivate * decrPlugin = 0;
     NMVariantMapMap result;
@@ -142,7 +144,7 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
     if (!config) {
         mErrorMessage = i18n("File %1 could not be opened.", fileName);
         return result;
-    }
+        }
 
     KConfigGroup cg(config, "main");   // Keys&Values are stored under [main]
     if (cg.exists()) {
@@ -271,7 +273,23 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
             ipv4Data.insert("never-default", cg.readEntry("EnableLocalLAN"));
         }
         if (!decrPlugin->readStringKeyValue(cg,"X-NM-Routes").isEmpty()) {
-            ipv4Data.insert("X-NM-Routes", decrPlugin->readStringKeyValue(cg,"X-NM-Routes"));
+            QList<NetworkManager::IpRoute> list;
+            foreach (const QString &route, decrPlugin->readStringKeyValue(cg,"X-NM-Routes").split(' ')) {
+                NetworkManager::IpRoute ipRoute;
+                ipRoute.setIp(QHostAddress(route.split('/').first()));
+                ipRoute.setPrefixLength(route.split('/').at(1).toInt());
+                list << ipRoute;
+            }
+            QList<QList<uint> > dbusRoutes;
+            foreach (const NetworkManager::IpRoute &route, list) {
+                QList<uint> dbusRoute;
+                dbusRoute << htonl(route.ip().toIPv4Address())
+                        << route.prefixLength()
+                        << htonl(route.nextHop().toIPv4Address())
+                        << route.metric();
+                dbusRoutes << dbusRoute;
+            }
+            ipv4Data.insert("routes", QVariant::fromValue(dbusRoutes));
         }
 
         // Set the '...-type' and '...-flags' value also
